z/VM Cloud Connector
********************

Description
===========
z/VM cloud connector is a development sdk for manage z/VM. It provides a set of APIs to operate z/VM including guest, image, network, volume etc.

Just like os-win for nova hyperv driver and oslo.vmware for nova vmware driver, z/VM cloud connector (zVMCloudConnector) is for nova z/vm driver and other z/VM related openstack driver such as neutron, ceilometer.

Quickstart
==========
Please refer to `Quick Start Guide <https://cloudlib4zvm.readthedocs.io/en/latest/quickstart.html>`_.

Documentation
==========
Please refer to `Documentation of z/VM Cloud Connector <https://cloudlib4zvm.readthedocs.io/en/latest/index.html>`_.

License
=======
This package is licensed under the `Apache 2.0 License`_.

.. _Apache 2.0 License: https://raw.githubusercontent.com/zhmcclient/python-zhmcclient/master/LICENSE

Bug reporting
=============
If you encounter any problem with this package, please open a bug against
`cloud connector issue tracker`_

.. _cloud connector issue tracker: https://bugs.launchpad.net/python-zvm-sdk/+bug
